#!/bin/sh

export PATH=/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin

PRODUCT_ROOT_D=`grep PRODUCT_ROOT_D /etc/psa/psa.conf | awk '{print $2}'`
DUMP_D=`grep DUMP_D /etc/psa/psa.conf | awk '{print $2}'`

if [ -f ${REINSTALL_DATA_ROOT}/usr/bin/mysqld_safe ]; then
  SAFEMYSQL=mysqld_safe
else
  SAFEMYSQL=safe_mysqld
fi

# 1. Start chrooted mysqld (if it's not started already)
if [ -f ${REINSTALL_DATA_ROOT}/tmp/mysqld.chrooted.pid -a -s ${REINSTALL_DATA_ROOT}/tmp/mysqld.chrooted.pid ]; then
  PID=`cat ${REINSTALL_DATA_ROOT}/tmp/mysqld.chrooted.pid`
  ps ${PID} > /dev/null
  if [ $? -ne 0 ]; then
    rm -f ${REINSTALL_DATA_ROOT}/tmp/mysqld.chrooted.pid 
	chroot ${REINSTALL_DATA_ROOT} ${SAFEMYSQL} --skip-networking --skip-grant-tables --pid-file=/tmp/mysqld.chrooted.pid  > /dev/null 2>&1 &
  fi
fi

if [ ! -f ${REINSTALL_DATA_ROOT}/tmp/mysqld.chrooted.pid ]; then
	chroot ${REINSTALL_DATA_ROOT} ${SAFEMYSQL} --skip-networking --skip-grant-tables --pid-file=/tmp/mysqld.chrooted.pid  > /dev/null 2>&1 &
fi

# 2. Prepare backup agent
TMPDIR=`mktemp -d ${REINSTALL_DATA_ROOT}/tmp/plesk_ve_reinstall-XXXXXXX`/1 # /1 is needed because agent_copy doesn`t copy agent into existing directory
CHROOTMPDIR=${TMPDIR#${REINSTALL_DATA_ROOT}}

${PRODUCT_ROOT_D}/admin/sbin/agent_copy ${TMPDIR}

# 3. Run backup, piping output to the new filesystem
chroot ${REINSTALL_DATA_ROOT} sh -c "cd ${CHROOTMPDIR} && perl PleskX.pl --server --output=-" \
 1>${DUMP_D}/plesk.chrooted.bak 2>${DUMP_D}/plesk.chrooted.error.log

# Restore process
# 4. Generate default mappings
${PRODUCT_ROOT_D}/bin/pleskrestore --create-map ${DUMP_D}/plesk.chrooted.bak -map ${DUMP_D}/plesk.chrooted.map

# 5. Start restore according to mappings made
${PRODUCT_ROOT_D}/bin/pleskrestore --restore ${DUMP_D}/plesk.chrooted.bak -license -level all -map ${DUMP_D}/plesk.chrooted.map -nowarning
